//! Simple frontend for the assembler

use msp430_asm::preamble::*;
use std::io::Read;

fn main() -> Result<(), Error> {
    let mut repl = true;
    for arg in std::env::args() {
        match arg.as_str() {
            "-" | "-f" | "--file" => repl = false,
            _ => (),
        }
    }

    let mut buf = String::new();
    if repl {
        while let Ok(len) = std::io::stdin().read_line(&mut buf) {
            match len {
                0 => break, // No newline (reached EOF)
                1 => {
                    // create a token steam
                    match Parser::default().parse(&buf) {
                        Ok(tree) => println!("{tree:x}"),
                        Err(error) => println!("{error}"),
                    }
                    buf.clear(); // Reuse buf's allocation
                    continue;
                } // Line is empty
                _ => (),
            }
        }
    } else {
        std::io::stdin().lock().read_to_string(&mut buf).map_err(|_| Error::EndOfFile)?;
        let tree = Parser::default().parse(&buf);
        match &tree {
            Ok(tree) => println!("{tree:x}"),
            Err(error) => eprintln!("{error}"),
        }
    }

    Ok(())
}
